#include <amxmodx>
#include <engine>
#include <fakemeta>
#include <ttt>

new const g_iDSprite[] = "sprites/ttt/team_d.spr";
new const g_iTSprite[] = "sprites/ttt/team_t.spr";

new cvar_show_health;
new g_iStatusSync, g_iKarmaSync, g_iDetectiveSpr, g_iTraitorSpr, g_iActiveTarget[33];

public plugin_precache()
{
	g_iDetectiveSpr = precache_model(g_iDSprite);
	g_iTraitorSpr = precache_model(g_iTSprite);
}

public plugin_init()
{
	register_plugin("[TTT] Special player info", TTT_VERSION, TTT_AUTHOR);
	cvar_show_health = register_cvar("ttt_show_health", "1");

	register_event("StatusValue", "Event_StatusValue_S", "be", "1=2", "2!0");
	register_event("StatusValue", "Event_StatusValue_H", "be", "1=1", "2=0");

	g_iStatusSync = CreateHudSyncObj();
	g_iKarmaSync = CreateHudSyncObj();
}

public client_putinserver(id)
{
	set_task(1.0, "show_status", id, _, _, "b");
}

public client_disconnect(id)
{
	if(task_exists(id))
		remove_task(id);
}

public client_PreThink(id)
{
	if(ttt_return_check(id))
		return;

	new ent;
	if((ent = find_that_ent(id, 60.0, TTT_DEADBODY)))
	{
		new target = entity_get_int(ent, EV_INT_iuser1);
		if(is_user_alive(target))
			return;
	
		new R, G = 50, B;
		static name[32], out[64];
		get_user_name(target, name, charsmax(name));
		new killedstate = ttt_get_playerdata(target, PD_KILLEDSTATE);

		if(ttt_get_playerdata(target, PD_IDENTIFIED))
		{
			if(killedstate == DETECTIVE)
				B = TTT_B;
			else if(killedstate == TRAITOR)
				R = TTT_R;
			else G = TTT_G;
			formatex(out, charsmax(out), "%L", id, special_names[killedstate]);
		}
		else
		{
			R = 255;
			G = 222;
			if(ttt_get_special_state(id) == TRAITOR)
				formatex(out, charsmax(out), "%L --- [%L]", id, "TTT_UNIDENTIFIED", id, special_names[killedstate]);
			else formatex(out, charsmax(out), "%L", id, "TTT_UNIDENTIFIED");
		}

		set_hudmessage(R, G, B, -1.0, 0.60, 1, 0.01, 0.01, 0.05, 0.01, -1);
		ShowSyncHudMsg(id, g_iStatusSync, "%s", out);
	}
	else if((ent = find_that_ent(id, 60.0, TTT_DEATHSTATION)))
	{
		new target = entity_get_int(ent, EV_INT_iuser1);
		if(!is_user_connected(target))
			return;

		static name[32];
		get_user_name(target, name, charsmax(name));
		if(ttt_get_special_state(id) == TRAITOR)
		{
			set_hudmessage(TTT_R, 50, 0, -1.0, 0.60, 1, 0.01, 0.05, 0.01, 0.01, -1);
			ShowSyncHudMsg(id, g_iStatusSync, "%s --- [%L]", name, id, "TTT_ITEM_ID8");
		}
	}
}

public Event_StatusValue_S(id)
{
	if(!is_user_connected(id) || ttt_get_game_state() == ENDED)
		return;

	static name[32];
	new message[128];
	new pid = read_data(2);
	get_user_name(pid, name, charsmax(name));
	new R, G = 50, B;

	new pidState = ttt_get_special_state(pid), idState = ttt_get_special_state(id);
	if(pidState == DETECTIVE)
		B = TTT_B;
	else if(pidState == TRAITOR && idState == TRAITOR)
		R = TTT_R;
	else G = TTT_G;

	new karma = ttt_get_playerdata(pid, PD_KARMA);
	set_hudmessage(R, G, B, -1.0, 0.60, 1, 0.01, 3.0, 0.01, 0.01, -1);
	remove_special_sprite(id, g_iActiveTarget[id]);

	if(get_pcvar_num(cvar_show_health))
		formatex(message, charsmax(message), "%s -- [Karma = %d] [HP = %d]", name, karma, get_user_health(pid));
	else formatex(message, charsmax(message), "%s -- [Karma = %d]", name, karma);

	if((idState == INNOCENT || idState == DETECTIVE) && pidState != DETECTIVE)
	{
		if(!ttt_get_hide_name(pid))
			ShowSyncHudMsg(id, g_iStatusSync, "%s", message);
	}
	else if(pid != g_iActiveTarget[id])
	{
		if(ttt_get_game_state() == PREPARING || ttt_get_game_state() == OFF)
			ShowSyncHudMsg(id, g_iStatusSync, "%s", message);
		else 
		{
			format(message, charsmax(message), "[%L] %s", id, special_names[pidState], message);
			ShowSyncHudMsg(id, g_iStatusSync, "%s", message);
		}

		if(pidState == DETECTIVE)
			show_special_sprite(id, pid, DETECTIVE);
		else if(pidState == TRAITOR && idState == TRAITOR)
			show_special_sprite(id, pid, TRAITOR);
	}

	g_iActiveTarget[id] = pid;
}

public Event_StatusValue_H(id)
{
	ClearSyncHud(id, g_iStatusSync);
	remove_special_sprite(id, g_iActiveTarget[id]);
}

public show_special_sprite(id, target, which)
{
	if(!is_user_connected(id) || !is_user_connected(target))
		return;

	message_begin(MSG_ONE, SVC_TEMPENTITY, _, id);
	write_byte(TE_PLAYERATTACHMENT);
	write_byte(target);
	write_coord(45);
	if(which == TRAITOR)
		write_short(g_iTraitorSpr);
	else if(which == DETECTIVE)
		write_short(g_iDetectiveSpr);
	write_short(30);
	message_end();
}

public remove_special_sprite(id, target)
{
	if(!is_user_connected(id) || !is_user_connected(target))
		return;

	message_begin(MSG_ONE, SVC_TEMPENTITY, _, id);
	write_byte(TE_KILLPLAYERATTACHMENTS);
	write_byte(target);
	message_end();

	g_iActiveTarget[id] = 0;
}

public show_status(alive)
{
	new dead = alive;
	if(!is_user_alive(dead))
	{
		alive = entity_get_int(dead, EV_INT_iuser2);
		if(!is_user_alive(alive))
			return;
	}

	new R, G = 50, B;
	if(ttt_get_special_state(dead) == DEAD || ttt_get_special_state(dead) == NONE)
		G = TTT_G;
	else
	{
		if(ttt_get_special_state(alive) == DETECTIVE)
			B = TTT_B;
		else if(ttt_get_special_state(alive) == TRAITOR)
			R = TTT_R;
		else G = TTT_G;
	}
	
	set_hudmessage(R, G, B, 0.02, 0.87, 0, 6.0, 1.1, 0.0, 0.0, -1);
	new karma = ttt_get_playerdata(alive, PD_KARMA);

	if(ttt_get_special_state(dead) == DEAD || ttt_get_special_state(dead) == NONE)
		ShowSyncHudMsg(dead, g_iKarmaSync, "[Karma = %d]", karma);
	else if(ttt_get_special_state(alive) != DETECTIVE && ttt_get_special_state(alive) != TRAITOR)
		ShowSyncHudMsg(alive, g_iKarmaSync, "[Karma = %d] [%L]", karma, alive, special_names[ttt_get_special_state(alive)]);
	else ShowSyncHudMsg(alive, g_iKarmaSync, "[Karma = %d] [%L] [Credits = %d]", karma, alive, special_names[ttt_get_special_state(alive)], ttt_get_playerdata(alive, PD_CREDITS));
}